package com.ibm.ctg.ping;
/**
*   Class: Constants
*   
*   Support pack for IBM CICS Transaction Gateway Version v5.0 to v7.2 
*
*   Version       : 1.3
*
*   Description   : Connects to a specified Gateway daemon, issues requests
*   and measures the time taken for operations to complete. This is useful for 
*   testing and debugging connectivity and performance.
*
*   See support pack documentation for details on how to configure and use this
*   sample. Also see the support pack for information on configuration necessary on
*   CICS.
*   
*   Licensed Materials - Property of IBM
*
*   Copyright IBM Corporation 2007,2008
*   All Rights Reserved
*
*   US Government Users Restricted Rights - Use,
*   duplication, or disclosure restricted by GSA
*   Schedule Contract with IBM Corporation
*
*
*   The following code is sample code created by IBM Corporation.  This
*   sample code is not part of any standard IBM product and is provided
*   to you solely for the purpose of assisting you in the development of
*   your applications.  The code is provided 'AS IS', without warranty
*   or condition of any kind.  IBM shall not be liable for any damages
*   arising out of your use of the sample code, even if IBM has been
*   advised of the possibility of such damages.
* 
*/

public interface Constants {
   static final int LIST_SYSTEMS_MAX_SYSTEMS = 99;

   /**
    *  ErrorStore codes returned by the main function. They are also
    *  used internally to control logic in the event of a failure.
    */
   static final int RC_OK              = 0;
   static final int INVALID_PARAMETERS = 4;
   static final int OPEN_FAIL          = 8;
   static final int RC_REQUEST_FAIL    = 12;
   static final int CLOSE_FAIL         = 16;
   static final int UNEXPECTED_ERROR   = 20;
   static final int HELP_SPECIFIED     = 24;
   
   /*
    * The following variables represent defaults that can be overridden by
    * command line parameters.
    */
   
   /** 
    * The default number of iterations if none is specified on the command line.
    */
   static final int DEFAULT_ITERATIONS = 5;

   /**
    * The number of ping requests that are issued per iteration if none is specified
    * on the command line.
    */
   static final int DEFAULT_REQUESTS = 5;
   
   /*
    * The following variables represent defaults that can not be overridden by
    * the command line. To configure these behaviours change the variable's value
    * and recompile the application.
    */
   
   /**
    * The default think-time in milli-seconds between each request within an iteration
    * and between each individual iteration. This is not configurable on the
    * command line. Set to 0 if you want ping to have no think time at all.
    */
   static final int DEFAULT_INTERVAL = 100;
   
   /**
    * The minimum time that will be displayed in seconds. Set to a value greater
    * than 0 to activate. For example if you set to 5s and a response is less
    * than 5 seconds <5 will be output.
    */
   static final int MIN_TIME = 0;

   /**
    * The transaction that will be used for the CICS ping. This is not configurable
    * via the command line.
    */
   static final String CICS_COMMAREA_TXN = "PONG";
   static final String CICS_CHANNELS_TXN = "PONGLONG";
   
   /**
    * Names of channel and container to use. PONGLONG is coded to look for
    * these values.
    */
   static final String CONTAINER_NAME = "INPUTDATA";
   static final String CHANNEL_NAME = "BIGBUCKET";

   /**
    * The default commarea size. This is set to 140 so that it is approximately the
    * same as the data size for a list systems request. Ctgping calls list systems if
    * no transaction is specific. Keeping the data sizes the same makes it possible
    * to compare performance between the two.
    */
   static final int DEFAULT_CALEN = 140;
   static final int MAX_LEN = 100000000;
   static final int MAX_CALEN = 32500;
   static final int MIN_CALEN = 1;
   
   static final int KILOBYTES = 1024;
   static final int NONE = 1;
   
}
