package com.ibm.ctg.ping;
/**
*   Class:  ErrorStore
*   
*   Support pack for IBM CICS Transaction Gateway Version v5.0 to v7.2 
*
*   Version       : 1.3
*
*   Description   : Connects to a specified Gateway daemon, issues requests
*   and measures the time taken for operations to complete. This is useful for 
*   testing and debugging connectivity and performance.
*
*   See support pack documentation for details on how to configure and use this
*   sample. Also see the support pack for information on configuration necessary on
*   CICS.
*   
*   Licensed Materials - Property of IBM
*
*   Copyright IBM Corporation 2007,2008
*   All Rights Reserved
*
*   US Government Users Restricted Rights - Use,
*   duplication, or disclosure restricted by GSA
*   Schedule Contract with IBM Corporation
*
*
*   The following code is sample code created by IBM Corporation.  This
*   sample code is not part of any standard IBM product and is provided
*   to you solely for the purpose of assisting you in the development of
*   your applications.  The code is provided 'AS IS', without warranty
*   or condition of any kind.  IBM shall not be liable for any damages
*   arising out of your use of the sample code, even if IBM has been
*   advised of the possibility of such damages.
* 
*/

import com.ibm.ctg.client.exceptions.ChannelException;

public class ErrorStore {

   static ErrorStore singletonInstance=null;
   
   public static ErrorStore getInstance() {
      if (singletonInstance==null) {
         singletonInstance=new ErrorStore();
      } 
      return singletonInstance;
   }
   
   private ErrorStore() {
   }
   
   /**
    * If a Gateway daemon or CICS ping request fails we output the first error
    * to the user. TxnError and TxnErrorString are set if an error occurs.
    */
   private boolean txnError = false;

   private String txnErrorString = null;
   
   /**
    * Stores the error string. Only sets the string the first time, subsequent
    * calls to this function are ignored. This encourages the user to diagnose
    * the first problem they hit, and doesn't flood them with errors.
    * 
    * @param error
    */
   public void set(String error) {
      if (!txnError) {
         // We store the first txn error we get to help the user diagnose
         // problems
         // without flooding them with errors
         txnError = true;
         txnErrorString = error;
      }
   }

   public String getErrorString() {
      return txnErrorString;
   }
   
   void set(Exception e) {
      set(e.toString());
   }

   public boolean hasErrorOccurred() {
      return txnError;
   }

   public void set(ChannelException e) {
      set(e.toString());
      
   }
   
   /**
    * Resets any error codes. This is used for unit testing of the
    * code.
    */
   public void reset() {
      txnError=false;
      txnErrorString = null;
   }
}
