      *
      * Module Name        ponglong.ccp
      *
      * Descriptive Name   Backend transaction for use with the
      *                    CTGping utility.
      *
      * Licensed Materials - Property of IBM
      *
      * 5724-I81 5724-J09
      *
      * (c) Copyright IBM Corp. 2008
      *
      * US Government Users Restricted Rights - Use, duplication or
      * disclosure restricted by GSA ADP Schedule Contract with
      * IBM Corp.
      *
      * Status: Version 1 Release 3
      * Notes :-
      *
      * PONGLONG is used by the CTGping utility to provide basic network
      * statistics with the channels and containers API.
      *
      * The following code is sample code created by IBM Corporation.
      * This sample code is not part of any standard IBM product and
      * is provided to you solely for the purpose of assisting you in
      * the development of your applications.  The code is provided
      * 'as is', without warranty or condition of any kind.  IBM shall
      * not be liable for any damages arising out of your use of the
      * sample code, even if IBM has been advised of the possibility
      * of such damages.
      *

       IDENTIFICATION DIVISION.

       PROGRAM-ID. PONGLONG.
      * SAMPLE DPL/ECI BASED APPLICATION SUPPLIED WITH CH50
      * CICS BACK END FOR A LINK WITH COMMAREA
      * OUTPUT: COMMAREA INPUT LENGTH

       ENVIRONMENT DIVISION.
       DATA DIVISION.

       WORKING-STORAGE SECTION.

      *  Container names
      *  Channel and container names are case sensitive
       01 INPUT-CONT         PIC X(16) VALUE 'INPUTDATA'.

      *  Data fields used by the program
       01 INPUTLENGTH        PIC S9(8) COMP-4.
       01 CHANNELNAME        PIC X(16) VALUE 'BIGBUCKET'.
       01 OUTPUTSTRING       PIC X(64) VALUE SPACES.
       01 RESPCODE           PIC S9(8) COMP-4 VALUE 0.
       01 RESPCODE2          PIC S9(8) COMP-4 VALUE 0.

       01 DATAPTR            USAGE IS POINTER.

       LINKAGE SECTION.
       01 CONTAINER-STRUCT.
         02 FIRSTBYTE          PIC X.

       PROCEDURE DIVISION.
       MAIN-PROCESSING SECTION.

      *  Get name of channel
           EXEC CICS ASSIGN CHANNEL(CHANNELNAME)
                            END-EXEC.

      *  If no channel passed in, terminate with abend code NOCH
           IF CHANNELNAME = SPACES THEN
               EXEC CICS ABEND ABCODE('NOCH') NODUMP
                            END-EXEC
           END-IF.

      *  Read contents and length of container INPUTDATA
           EXEC CICS GET CONTAINER(INPUT-CONT)
                            CHANNEL(CHANNELNAME)
                            SET(DATAPTR)
                            RESP(RESPCODE)
                            RESP2(RESPCODE2)
                            FLENGTH(INPUTLENGTH)
                            END-EXEC.

      *  Check response code
           EVALUATE RESPCODE

      *  Container not passed in
             WHEN DFHRESP(CONTAINERERR)
               STRING INPUT-CONT
                            DELIMITED BY SPACE
                      ' container was not passed to the program'
                            DELIMITED BY SIZE
                            INTO OUTPUTSTRING END-STRING

             WHEN DFHRESP(LENGERR)
               STRING INPUT-CONT
                            DELIMITED BY SPACE
                      ' invalid input data length'
                            DELIMITED BY SIZE
                            INTO OUTPUTSTRING END-STRING

      *  Container is CHAR not BIT
             WHEN DFHRESP(CCSIDERR)
               IF RESPCODE2 = 3
                 STRING 'Container '
                            DELIMITED BY SIZE
                        INPUT-CONT
                            DELIMITED BY SPACE
                        ' type is CHAR, not BIT'
                            DELIMITED BY SIZE
                            INTO OUTPUTSTRING END-STRING
               ELSE
                 STRING 'The GET CONTAINER command returned an',
                        ' unexpected CCSIDERR condition'
                            DELIMITED BY SIZE
                            INTO OUTPUTSTRING END-STRING
               END-IF

      *  Read from container OK
             WHEN DFHRESP(NORMAL)
               STRING 'DATA received successfully'
                   DELIMITED BY SIZE
                   INTO OUTPUTSTRING END-STRING
      *  Other response code
             WHEN OTHER
               STRING 'The GET CONTAINER command returned an',
                      ' unexpected response code'
                            DELIMITED BY SIZE
                            INTO OUTPUTSTRING END-STRING

           END-EVALUATE.

      *  Check return code
           IF RESPCODE NOT = DFHRESP(NORMAL)
      * Write a message to the CICS log which explains why the abend occcured
               EXEC CICS WRITE OPERATOR
                   TEXT(OUTPUTSTRING)
               END-EXEC
               EXEC CICS ABEND ABCODE('GETC') NODUMP
                            END-EXEC
           END-IF.
      *  Change data, so that when it's PUT back to the client the data
      *  will be resent.
           SET ADDRESS OF CONTAINER-STRUCT TO DATAPTR
           MOVE 9 TO FIRSTBYTE
      *  Send results
           EXEC CICS PUT CONTAINER(INPUT-CONT)
                            FROM(DATAPTR)
                            FLENGTH(INPUTLENGTH)
                            BIT
                            RESP(RESPCODE)
                            END-EXEC.

      *  Check return code
           IF RESPCODE NOT = DFHRESP(NORMAL)
               EXEC CICS ABEND ABCODE('PUTC') NODUMP
                            END-EXEC
           END-IF.


      *  Finish
           EXEC CICS RETURN END-EXEC.

           EXIT.

